==> process-optaplanner-springboot-1.3.0.Final-sources.jar: org/kie/kogito/handlers/FlightSeatingSolveService_assignSeats_4_Handler.java <==
package org.kie.kogito.handlers;

import org.kie.kogito.process.workitem.WorkItemExecutionError;

@org.springframework.stereotype.Component()
public class FlightSeatingSolveService_assignSeats_4_Handler implements org.kie.kogito.internal.process.runtime.KogitoWorkItemHandler {

    org.kie.kogito.examples.service.FlightSeatingSolveService service;

    public FlightSeatingSolveService_assignSeats_4_Handler() {
        this(new org.kie.kogito.examples.service.FlightSeatingSolveService());
    }

    @org.springframework.beans.factory.annotation.Autowired()
    @org.springframework.context.annotation.Lazy()
    public FlightSeatingSolveService_assignSeats_4_Handler(org.kie.kogito.examples.service.FlightSeatingSolveService service) {
        this.service = service;
    }

    public void executeWorkItem(org.kie.kogito.internal.process.runtime.KogitoWorkItem workItem, org.kie.kogito.internal.process.runtime.KogitoWorkItemManager workItemManager) {
        service.assignSeats((String) workItem.getParameter("problemId"), (org.kie.kogito.examples.domain.Flight) workItem.getParameter("problem"));
        workItemManager.completeWorkItem(workItem.getStringId(), null);
    }

    public void abortWorkItem(org.kie.kogito.internal.process.runtime.KogitoWorkItem workItem, org.kie.kogito.internal.process.runtime.KogitoWorkItemManager workItemManager) {
    }

    public String getName() {
        return "org.kie.kogito.examples.service.FlightSeatingSolveService_assignSeats_4_Handler";
    }
}

==> process-optaplanner-springboot-1.4.1.Final-sources.jar: org/kie/kogito/handlers/FlightSeatingSolveService_assignSeats_4_Handler.java <==
package org.kie.kogito.handlers;

import org.kie.kogito.process.workitem.WorkItemExecutionException;

@org.springframework.stereotype.Component()
public class FlightSeatingSolveService_assignSeats_4_Handler implements org.kie.kogito.internal.process.runtime.KogitoWorkItemHandler {

    org.kie.kogito.examples.service.FlightSeatingSolveService service;

    public FlightSeatingSolveService_assignSeats_4_Handler() {
        this(new org.kie.kogito.examples.service.FlightSeatingSolveService());
    }

    @org.springframework.beans.factory.annotation.Autowired()
    @org.springframework.context.annotation.Lazy()
    public FlightSeatingSolveService_assignSeats_4_Handler(org.kie.kogito.examples.service.FlightSeatingSolveService service) {
        this.service = service;
    }

    public void executeWorkItem(org.kie.kogito.internal.process.runtime.KogitoWorkItem workItem, org.kie.kogito.internal.process.runtime.KogitoWorkItemManager workItemManager) {
        service.assignSeats((String) workItem.getParameter("problemId"), (org.kie.kogito.examples.domain.Flight) workItem.getParameter("problem"));
        workItemManager.completeWorkItem(workItem.getStringId(), null);
    }

    public void abortWorkItem(org.kie.kogito.internal.process.runtime.KogitoWorkItem workItem, org.kie.kogito.internal.process.runtime.KogitoWorkItemManager workItemManager) {
    }

    public String getName() {
        return "org.kie.kogito.examples.service.FlightSeatingSolveService_assignSeats_4_Handler";
    }
}
